@@ -1,4 +1,4 @@
-"""绘图类模块"""
+"""绘图类模块."""
 
 from typing import Union
 
@@ -13,39 +13,14 @@ from geopandas import GeoDataFrame
 from .maps import MapPolygon
 
 
-def clip_contours_by_map(contours, map_polygon: MapPolygon):
-    """使用地图边界对象对等值线对象进行裁剪
-
-    参数:
-        contours (cartopy.mpl.contour.GeoContourSet): 等值线对象, 该对象是调用ax.contour()或ax.contourf()方法的返回值
-                                                      注意: 对象须带有投影信息
-        map_polygon (MapPolygon): 地图边界对象, 可以通过get_map()获取
-
-    示例:
-        >>> from cnmaps import get_adm_maps, clip_contours_by_map, draw_map
-        >>> from cnmaps.sample import load_dem
-
-        >>> lons, lats, data = load_dem()
-
-        >>> fig = plt.figure(figsize=(10, 10))
-        >>> ax = fig.add_subplot(111, projection=ccrs.PlateCarree())
-        >>> map_polygon = get_adm_maps(country='中华人民共和国', record='first', only_polygon=True)
-
-        >>> cs = ax.contourf(lons,
-                             lats,
-                             data,
-                             cmap=plt.cm.terrain,
-                             levels=np.linspace(-2800, data.max(), 10),
-                             transform=ccrs.PlateCarree())
-
-        >>> clip_contours_by_map(cs, map_polygon)
-        >>> draw_map(map_polygon, color='k', linewidth=1)
-    """
+def _make_clip_path(map_polygon):
     vertices = []
     codes = []
     ax = plt.gca()
+    clips = []
+    crs = ccrs.PlateCarree()
 
-    for polygon in map_polygon:
+    for polygon in map_polygon.geoms:
         try:
             coords = polygon.boundary.coords
         except NotImplementedError:
@@ -55,8 +30,7 @@ def clip_contours_by_map(contours, map_polygon: MapPolygon):
             exterior_prt = len(exterior_coords)
             for coord in exterior_coords:
                 try:
-                    trans_coord = ax.projection.transform_point(
-                        *coord, src_crs=ccrs.PlateCarree())
+                    trans_coord = ax.projection.transform_point(*coord, crs)
                 except AttributeError:
                     trans_coord = coord
                 vertices.append(trans_coord)
@@ -68,8 +42,7 @@ def clip_contours_by_map(contours, map_polygon: MapPolygon):
                 interior_prt = len(interior_coords)
                 for coord in interior_coords:
                     try:
-                        trans_coord = ax.projection.transform_point(
-                            *coord, src_crs=ccrs.PlateCarree())
+                        trans_coord = ax.projection.transform_point(*coord, crs)
                     except AttributeError:
                         trans_coord = coord
                     vertices.append(trans_coord)
@@ -82,8 +55,7 @@ def clip_contours_by_map(contours, map_polygon: MapPolygon):
             prt = len(coords)
             for coord in coords:
                 try:
-                    trans_coord = ax.projection.transform_point(
-                        *coord, src_crs=ccrs.PlateCarree())
+                    trans_coord = ax.projection.transform_point(*coord, crs)
                 except AttributeError:
                     trans_coord = coord
                 vertices.append(trans_coord)
@@ -93,15 +65,56 @@ def clip_contours_by_map(contours, map_polygon: MapPolygon):
             clip = mpath.Path(vertices, codes)
         clip = mpatches.PathPatch(clip, transform=ax.transData)
 
+        clips.append(clip)
+
+    return clips
+
+
+def clip_contours_by_map(contours, map_polygon: MapPolygon):
+    """
+    使用地图边界对象对等值线对象进行裁剪
+
+    参数:
+        contours (cartopy.mpl.contour.GeoContourSet): 等值线对象,
+                    该对象是调用ax.contour()或ax.contourf()方法的返回值
+                    注意: 对象须带有投影信息
+        map_polygon (MapPolygon): 地图边界对象, 可以通过get_map()获取
+
+    示例:
+        >>> from cnmaps import get_adm_maps, clip_contours_by_map, draw_map
+        >>> from cnmaps.sample import load_dem
+
+        >>> lons, lats, data = load_dem()
+
+        >>> fig = plt.figure(figsize=(10, 10))
+        >>> ax = fig.add_subplot(111, projection=ccrs.PlateCarree())
+        >>> map_polygon = get_adm_maps(country='中华人民共和国', record='first',
+            only_polygon=True)
+
+        >>> cs = ax.contourf(lons,
+                             lats,
+                             data,
+                             cmap=plt.cm.terrain,
+                             levels=np.linspace(-2800, data.max(), 10),
+                             transform=ccrs.PlateCarree())
+
+        >>> clip_contours_by_map(cs, map_polygon)
+        >>> draw_map(map_polygon, color='k', linewidth=1)
+    """
+    clips = _make_clip_path(map_polygon)
+
+    for clip in clips:
         for contour in contours.collections:
             contour.set_clip_path(clip)
 
 
 def clip_pcolormesh_by_map(mesh, map_polygon: MapPolygon):
-    """使用地图边界对象对填色网格线对象进行裁剪
+    """
+    使用地图边界对象对填色网格线对象进行裁剪
 
     参数:
-        mesh (cartopy.mpl.geocollection.GeoQuadMesh): GeoQuadMesh对象, 该对象是调用ax.pcolormesh()方法的返回值
+        mesh (cartopy.mpl.geocollection.GeoQuadMesh): GeoQuadMesh对象,
+                                                      该对象是调用ax.pcolormesh()方法的返回值
                                                       注意: 对象须带有投影信息
         map_polygon (MapPolygon): 地图边界对象, 可以通过get_map()获取
 
@@ -125,64 +138,15 @@ def clip_pcolormesh_by_map(mesh, map_polygon: MapPolygon):
     >>> clip_pcolormesh_by_map(mesh, map_polygon)
     >>> draw_map(map_polygon, linewidth=1)
     """
-    vertices = []
-    codes = []
-    ax = plt.gca()
-
-    for polygon in map_polygon:
-        try:
-            coords = polygon.boundary.coords
-        except NotImplementedError:
-            # 针对图形中出现了洞的情况的处理
-            exterior_coords = polygon.exterior.coords
-            interiors = polygon.interiors
-            exterior_prt = len(exterior_coords)
-            for coord in exterior_coords:
-                try:
-                    trans_coord = ax.projection.transform_point(
-                        *coord, src_crs=ccrs.PlateCarree())
-                except AttributeError:
-                    trans_coord = coord
-                vertices.append(trans_coord)
-            codes += [mpath.Path.MOVETO]
-            codes += [mpath.Path.LINETO] * (exterior_prt - 2)
-            codes += [mpath.Path.CLOSEPOLY]
-            for interior in interiors:
-                interior_coords = interior.coords
-                interior_prt = len(interior_coords)
-                for coord in interior_coords:
-                    try:
-                        trans_coord = ax.projection.transform_point(
-                            *coord, src_crs=ccrs.PlateCarree())
-                    except AttributeError:
-                        trans_coord = coord
-                    vertices.append(trans_coord)
-                codes += [mpath.Path.MOVETO]
-                codes += [mpath.Path.LINETO] * (interior_prt - 2)
-                codes += [mpath.Path.CLOSEPOLY]
-
-            clip = mpath.Path(vertices, codes)
-        else:
-            prt = len(coords)
-            for coord in coords:
-                try:
-                    trans_coord = ax.projection.transform_point(
-                        *coord, src_crs=ccrs.PlateCarree())
-                except AttributeError:
-                    trans_coord = coord
-                vertices.append(trans_coord)
-            codes += [mpath.Path.MOVETO]
-            codes += [mpath.Path.LINETO] * (prt - 2)
-            codes += [mpath.Path.CLOSEPOLY]
-            clip = mpath.Path(vertices, codes)
-        clip = mpatches.PathPatch(clip, transform=ax.transData)
+    clips = _make_clip_path(map_polygon)
 
+    for clip in clips:
         mesh.set_clip_path(clip)
 
 
-def clip_clabels_by_map(clabel_text: matplotlib.text.Text,
-                        map_polygon: MapPolygon):
-    """剪切clabel文本, 一般配合contour函数使用
+def clip_clabels_by_map(clabel_text: matplotlib.text.Text, map_polygon: MapPolygon):
+    """
+    剪切clabel文本, 一般配合contour函数使用
 
     注意: 该函数仅对于cartopy>=0.19.0版本有效
 
@@ -191,7 +155,11 @@ def clip_clabels_by_map(clabel_text: matplotlib.text.Text,
         map_polygon (MapPolygon): 地图多边形边界对象
 
     示例:
-    >>> from cnmaps import get_adm_maps, clip_clabels_by_map, clip_contours_by_map, draw_map
+    >>> from cnmaps import (
+        get_adm_maps,
+        clip_clabels_by_map,
+        clip_contours_by_map,
+        draw_map)
     >>> from cnmaps.sample import load_dem
 
     >>> lons, lats, data = load_dem()
@@ -216,11 +184,12 @@ def clip_clabels_by_map(clabel_text: matplotlib.text.Text,
     >>> draw_map(map_polygon, color='k')
     """
     ax = plt.gca()
+    crs = ccrs.PlateCarree()
 
     for cbt in clabel_text:
         cbt.set_visible(False)
 
-    for polygon in map_polygon:
+    for polygon in map_polygon.geoms:
         vertices = []
         try:
             coords = polygon.boundary.coords
@@ -231,8 +200,7 @@ def clip_clabels_by_map(clabel_text: matplotlib.text.Text,
             interiors = polygon.interiors
             for coord in exterior_coords:
                 try:
-                    trans_coord = ax.projection.transform_point(
-                        *coord, src_crs=ccrs.PlateCarree())
+                    trans_coord = ax.projection.transform_point(*coord, crs)
                 except AttributeError:
                     trans_coord = coord
                 vertices.append(trans_coord)
@@ -241,8 +209,7 @@ def clip_clabels_by_map(clabel_text: matplotlib.text.Text,
                 interior_coords = interior.coords
                 for coord in interior_coords:
                     try:
-                        trans_coord = ax.projection.transform_point(
-                            *coord, src_crs=ccrs.PlateCarree())
+                        trans_coord = ax.projection.transform_point(*coord, crs)
                     except AttributeError:
                         trans_coord = coord
                     hole.append(trans_coord)
@@ -251,8 +218,7 @@ def clip_clabels_by_map(clabel_text: matplotlib.text.Text,
         else:
             for coord in coords:
                 try:
-                    trans_coord = ax.projection.transform_point(
-                        *coord, src_crs=ccrs.PlateCarree())
+                    trans_coord = ax.projection.transform_point(*coord, crs)
                 except AttributeError:
                     trans_coord = coord
                 vertices.append(trans_coord)
@@ -264,12 +230,12 @@ def clip_clabels_by_map(clabel_text: matplotlib.text.Text,
                 cbt.set_visible(True)
 
 
-def draw_map(map_polygon: Union[MapPolygon, sgeom.MultiPolygon,
-                         sgeom.MultiLineString], **kwargs):
-    """绘制单个地图边界线
+def draw_map(map_polygon: Union[MapPolygon, sgeom.MultiLineString], **kwargs):
+    """
+    绘制单个地图边界线
 
     参数:
-        map_polygon (Union[MapPolygon, sgeom.MultiPolygon, sgeom.MultiLineString]): 地图边界线对象
+        map_polygon (Union[MapPolygon,  sgeom.MultiLineString]): 地图边界线对象
 
     示例:
         >>> beijing = get_adm_maps(city='北京市', level='市')[0]
@@ -287,19 +253,21 @@ def draw_map(map_polygon: Union[MapPolygon, sgeom.MultiPolygon,
         >>> draw_map(get_adm_maps(city='北京市', level='市', only_polygon=True, record='first'))
     """
     ax = plt.gca()
-    for geomestry in map_polygon:
+    crs = ccrs.PlateCarree()
+    for geometry in map_polygon.geoms:
         if isinstance(map_polygon, sgeom.MultiPolygon):
             try:
-                coords = geomestry.boundary.coords
+                coords = geometry.boundary.coords
             except NotImplementedError:
-                exterior_coords = geomestry.exterior.coords
-                interiors = geomestry.interiors
+                exterior_coords = geometry.exterior.coords
+                interiors = geometry.interiors
                 xs = []
                 ys = []
                 for coord in exterior_coords:
                     try:
                         x, y = ax.projection.transform_point(
-                            *coord, src_crs=ccrs.PlateCarree())
+                            *coord, src_crs=ccrs.PlateCarree()
+                        )
                     except AttributeError:
                         x, y = coord
                     xs.append(x)
@@ -312,8 +280,7 @@ def draw_map(map_polygon: Union[MapPolygon, sgeom.MultiPolygon,
                     ys = []
                     for coord in interior_coords:
                         try:
-                            x, y = ax.projection.transform_point(
-                                *coord, src_crs=ccrs.PlateCarree())
+                            x, y = ax.projection.transform_point(*coord, crs)
                         except AttributeError:
                             x, y = coord
                         xs.append(x)
@@ -321,25 +288,25 @@ def draw_map(map_polygon: Union[MapPolygon, sgeom.MultiPolygon,
                     ax.plot(xs, ys, **kwargs)
                 continue
         elif isinstance(map_polygon, sgeom.MultiLineString):
-            coords = geomestry.coords
+            coords = geometry.coords
         xs = []
         ys = []
         for coord in coords:
             try:
-                x, y = ax.projection.transform_point(
-                    *coord, src_crs=ccrs.PlateCarree())
+                x, y = ax.projection.transform_point(*coord, src_crs=crs)
             except AttributeError:
                 x, y = coord
             xs.append(x)
             ys.append(y)
-        if kwargs.get('color'):
+        if kwargs.get("color"):
             ax.plot(xs, ys, **kwargs)
         else:
-            ax.plot(xs, ys, color='k', **kwargs)
+            ax.plot(xs, ys, color="k", **kwargs)
 
 
 def draw_maps(maps: Union[list, GeoDataFrame], **kwargs):
-    """绘制多个地图边界
+    """
+    绘制多个地图边界
 
     参数:
         maps (Union[list, GeoDataFrame]): 地图边界列表或GeoDataFrame对象
@@ -349,7 +316,7 @@ def draw_maps(maps: Union[list, GeoDataFrame], **kwargs):
         >>> maps = get_adm_maps(city='北京市', level='区县')
         >>> maps[:3]
         [{'国家': '中华人民共和国', '省/直辖市': '北京市', '市': '北京市', '区/县': '东城区', '级别': '区县', '来源': '高德', '类型': '陆地', 'geometry': <cnmaps.maps.MapPolygon object at 0x7f92fe4676d0>}, {'国家': '中华人民共和国', '省/直辖市': '北京市', '市': '北京市', '区/县': '西城区', '级别': '区县', '来源': '高德', '类型': '陆地', 'geometry': <cnmaps.maps.MapPolygon object at 0x7f92fe467a50>}, {'国家': '中华人民共和国', '省/直辖市': '北京市', '市': '北京市', '区/县': '朝阳区', '级别': '区县', '来源': '高德', '类型': '陆地', 'geometry': <cnmaps.maps.MapPolygon object at 0x7f92fe467750>}]
-        >>> draw_maps(map) 
+        >>> draw_maps(map)
 
         >>> from cnmaps import get_adm_maps, draw_maps
         >>> maps = get_adm_maps(city='北京市', level='区县', engine='geopandas')
@@ -360,13 +327,13 @@ def draw_maps(maps: Union[list, GeoDataFrame], **kwargs):
         2  中华人民共和国   北京市  北京市  朝阳区  区县  高德  陆地  MULTIPOLYGON (((116.55172 40.05812, 116.55132 ...
     """
     if isinstance(maps, list):
-        geometries = [m['geometry'] for m in maps]
+        geometries = [m["geometry"] for m in maps]
     elif isinstance(maps, GeoDataFrame):
-        geometries = [m['geometry'] for _, m in maps.iterrows()]
+        geometries = [m["geometry"] for _, m in maps.iterrows()]
 
     for gm in geometries:
         draw_map(gm, **kwargs)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
